@@ -109,7 +109,7 @@ static void select_all (Side side);
 static void unselect_all (void);
 static Boolean all_selected (void);
 static Dimension get_preferred_width (Widget w);
-static char *basename (char *name);
+static char *mgdiff_basename (char *name);
 
 #define APP_DEFAULTS_VERSION 1
 
@@ -1018,7 +1018,7 @@ int main (int argc, char *argv[])
     {"debug", "Debug", XtRBoolean, sizeof (Boolean), 0, XtRString, "false"},
     {"filename", "Filename", XtRString, sizeof (String), 0, XtRString, ""}};
     
-    progname = basename (argv[0]);
+    progname = mgdiff_basename (argv[0]);
 
     toplevel = XtVaAppInitialize (&app, "Mgdiff", option_table, XtNumber (option_table),
 #if X11R5
@@ -2391,7 +2391,7 @@ static Dimension get_preferred_width (Widget w)
 /* 
  * delete any prefix ending in '/' and return a copy
  */
-static char *basename (char *path)
+static char *mgdiff_basename (char *path)
 {
     if (path) {
 	char *p;
